@@ -1,23 +1,9 @@
-/***************************************************************************
- *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *   Copyright © 2017 Jan Grulich <jgrulich@redhat.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2017 Jan Grulich <jgrulich@redhat.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #ifndef ODRSREVIEWSBACKEND_H
 #define ODRSREVIEWSBACKEND_H
@@ -31,11 +17,14 @@
 
 class KJob;
 class AbstractResourcesBackend;
+class CachedNetworkAccessManager;
+
 class DISCOVERCOMMON_EXPORT OdrsReviewsBackend : public AbstractReviewsBackend
 {
 Q_OBJECT
 public:
     explicit OdrsReviewsBackend();
+    ~OdrsReviewsBackend() override;
 
     QString userName() const override;
     void login() override {}
@@ -69,7 +58,7 @@ private:
 
     QHash<QString, Rating*> m_ratings;
     bool m_isFetching;
-    QNetworkAccessManager* m_delayedNam = nullptr;
+    CachedNetworkAccessManager* m_delayedNam = nullptr;
 };
 
 #endif // ODRSREVIEWSBACKEND_H
