@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *   Copyright © 2017 Jan Grulich <jgrulich@redhat.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2017 Jan Grulich <jgrulich@redhat.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
+
 
 #ifndef FLATPAKBACKEND_H
 #define FLATPAKBACKEND_H
@@ -31,9 +18,7 @@
 
 #include <AppStreamQt/component.h>
 
-extern "C" {
-#include <flatpak.h>
-}
+#include "flatpak-helper.h"
 
 class FlatpakSourcesBackend;
 class StandardBackendUpdater;
@@ -65,9 +50,14 @@ public:
 
     FlatpakResource * addAppFromFlatpakBundle(const QUrl &url);
     FlatpakResource * addAppFromFlatpakRef(const QUrl &url);
+    FlatpakResource * getAppForInstalledRef(FlatpakInstallation *flatpakInstallation, FlatpakInstalledRef *ref) const;
+
+    FlatpakSourcesBackend *sources() const { return m_sources; }
+
+    bool updateAppSize(FlatpakResource *resource);
 
 private Q_SLOTS:
-    void onFetchMetadataFinished(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource, const QByteArray &metadata);
+    void onFetchMetadataFinished(FlatpakResource *resource, const QByteArray &metadata);
     void onFetchSizeFinished(FlatpakResource *resource, guint64 downloadSize, guint64 installedSize);
     void onFetchUpdatesFinished(FlatpakInstallation *flatpakInstallation, GPtrArray *updates);
 
@@ -81,8 +71,7 @@ private:
     FlatpakInstallation * preferredInstallation() const { return m_installations.constFirst(); }
     void integrateRemote(FlatpakInstallation *flatpakInstallation, FlatpakRemote *remote);
     FlatpakRemote * getFlatpakRemoteByUrl(const QString &url, FlatpakInstallation *installation) const;
-    FlatpakInstalledRef * getInstalledRefForApp(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource) const;
-    FlatpakResource * getAppForInstalledRef(FlatpakInstallation *flatpakInstallation, FlatpakInstalledRef *ref) const;
+    FlatpakInstalledRef * getInstalledRefForApp(FlatpakResource *resource) const;
     FlatpakResource * getRuntimeForApp(FlatpakResource *resource) const;
 
     void addResource(FlatpakResource *resource);
@@ -96,12 +85,11 @@ private:
     void refreshAppstreamMetadata(FlatpakInstallation *installation, FlatpakRemote *remote);
     bool setupFlatpakInstallations(GError **error);
     void updateAppInstalledMetadata(FlatpakInstalledRef *installedRef, FlatpakResource *resource);
-    bool updateAppMetadata(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource);
+    bool updateAppMetadata(FlatpakResource *resource);
     bool updateAppMetadata(FlatpakResource *resource, const QByteArray &data);
     bool updateAppMetadata(FlatpakResource *resource, const QString &path);
-    bool updateAppSize(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource);
-    bool updateAppSizeFromRemote(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource);
-    void updateAppState(FlatpakInstallation *flatpakInstallation, FlatpakResource *resource);
+    bool updateAppSizeFromRemote(FlatpakResource *resource);
+    void updateAppState(FlatpakResource *resource);
 
     QVector<AbstractResource*> resourcesByAppstreamName(const QString &name) const;
     void acquireFetching(bool f);
