@@ -11,9 +11,7 @@
 
 #include <resources/AbstractResource.h>
 
-extern "C" {
-#include <flatpak.h>
-}
+#include "flatpak-helper.h"
 
 #include <AppStreamQt/component.h>
 
